@@ -5,7 +5,7 @@ from .event import BaseEvent
 from ..interfaces.dispatcher import DispatcherInterface
 from .dispatcher import BaseDispatcher
 
-class BaseRule(abc.ABC, BaseModel):
+class BaseRule(metaclass=abc.ABCMeta):
     target_dispatcher: BaseDispatcher
 
     def __init__(self, target_dispatcher: BaseDispatcher) -> None:
@@ -15,6 +15,9 @@ class BaseRule(abc.ABC, BaseModel):
     def check(self, event: BaseEvent, dii: DispatcherInterface) -> bool:
         pass
 
+    class Config:
+        arbitrary_types_allowed = True
+
 class SpecialEventType(BaseRule):
     target_dispatcher: BaseDispatcher
 
