@@ -1,12 +1,14 @@
 import itertools
-from typing import Any, AsyncGenerator, Callable, Generator, List, Optional, Set, Tuple, Type, Union, _GenericAlias
+from typing import (Any, AsyncGenerator, Callable, Generator, List, Optional,
+                    Set, Tuple, Type, Union, _GenericAlias)
 
 from ..entities.dispatcher import BaseDispatcher
 from ..entities.event import BaseEvent
 from ..entities.signatures import Force
-from ..exceptions import (OutOfMaxGenerater,
-                          RequirementCrashed)
-from ..utilles import as_sliceable, is_asyncgener, isgeneratorfunction, run_always_await, run_always_await_safely
+from ..exceptions import OutOfMaxGenerater, RequirementCrashed
+from ..utilles import (as_sliceable, is_asyncgener, isgeneratorfunction,
+                       run_always_await_safely)
+
 
 def get_raw_dispatcher_callable(dispatcher: Any):
   if isinstance(dispatcher, BaseDispatcher):
@@ -304,4 +306,4 @@ class DispatcherInterface:
   def getDispatcher(self, dispatcher_class: Type[BaseDispatcher]) -> Optional[BaseDispatcher]:
     for i in self.dispatchers:
       if type(i) is dispatcher_class:
-        return i
\ No newline at end of file
+        return i
